@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use 5.022;
+use 5.024;
 use feature qw /postderef signatures/;
 
 package Vote::Count::Matrix;
@@ -28,13 +28,13 @@ use Storable 3.15 'dclone';
 
 use YAML::XS;
 
-our $VERSION='1.10';
+our $VERSION='2.00';
 
 =head1 NAME
 
 Vote::Count::Matrix
 
-=head1 VERSION 1.10
+=head1 VERSION 2.00
 
 =cut
 
@@ -393,18 +393,14 @@ sub PairingVotesTable ( $self ) {
 
 1;
 
-#buildpod
-
 =pod
 
 =head1 Win-Loss Matrix
 
 Condorcet Pairwise Methods require a Win-Loss Matrix. This object takes an RCV BallotSet with an optional Active list and returns the Matrix as an object. The object is capable of Scoring itself, Calculating a Smith Set, and identifying Condorcet Winners and Losers.
 
-
 =head1 SYNOPSIS
 
-
  my $Matrix =
    Vote::Count::Matrix->new(
      'BallotSet' => $myVoteCount->BallotSet() );
@@ -412,53 +408,42 @@ Condorcet Pairwise Methods require a Win-Loss Matrix. This object takes an RCV B
    my %DominantSet = $Matrix->SmithSet()->%*;
    my $CondorcetWinner = $Matrix->CondorcetWinner();
 
-
-
 =head1 Tie Breakers
 
 A tie breaker may be specified by setting the Tie::Breaker attribute, see the Tie::Breaker module for more information. If using Range Ballots 'none' and 'approval' are the only currently supported options.
 
-
 =head2 new
 
 Parameters:
 
-
 =head3 BallotSet (required)
 
 A Ballot Set reference as generated by ReadBallots, which can be retrieved from a Vote::Count object via the ->BallotSet() method.
 
 Both Ranked Choice and Range BallotSets are supported.
 
-
 =head3 Active (optional)
 
 A hash reference with active choices as the keys. The default value is all of the choices defined in the BallotSet.
 
-
 =head3 Logging (optional)
 
 Has the logging methods of L.
 
-
 =head1 Methods
 
-
 =head2 MatrixTable
 
 Returns a MarkDown formatted table with the wins losses and ties for each Active Choice as text.
 
-
 =head2 PairingVotesTable
 
 Returns a MarkDown formatted table with the votes for all of the pairings.
 
-
 =head2 GetPairResult ( $A, $B )
 
 Returns the results of the pairing of two choices as a hashref.
 
-
    {
     'FUDGESWIRL' =>  6,
     'loser'      =>  "STRAWBERRY",
@@ -468,33 +453,26 @@ Returns the results of the pairing of two choices as a hashref.
     'winner'     =>  "FUDGESWIRL"
    }
 
-
-
 =head2 GetPairWinner ( $A, $B )
 
 Returns the winner of the pairing of two choices. If there is no Winner it returns a false value (empty string).
 
-
 =head2 ScoreMatrix
 
 Returns a HashRef of the choices and their Matrix Scores. The scoring is 1 for each win, 0 for losses and ties. In the event a choice has ties but no wins their score will be .001. Where N is the number of choices, a Condorcet Winner will have a score of N-1, a Condorcet Loser will have a score of 0. Since a choice with at least one tie but no wins is not defeated by all other choices they are not a Condorcet Loser, and thus those cases are scored with a near to zero value instead of 0. Methods that wish to treat no wins but tie case as a Condorcet Loser may test for a score less than 1.
 
-
 =head2 ScoreTable
 
 Returns the ScoreMatrix as a markdown compatible table.
 
-
 =head2 LeastWins
 
 Returns an array of the choice or choices with the fewest wins.
 
-
 =head2 CondorcetLoser
 
 Eliminates all Condorcet Losers from the Matrix Object's Active list. Returns a hashref. Takes an optional true false argument (default is false) to include choices that have tied but not won in the elimination.
 
-
    {
      verbose => 'verbose message',
      terse   => 'terse message',
@@ -502,38 +480,30 @@ Eliminates all Condorcet Losers from the Matrix Object's Active list. Returns a
      eliminations => number of eliminated choices,
    };
 
-
-
 =head2 CondorcetWinner
 
 Returns either the Condorcet Winner or an empty string if there is none.
 
-
 =head2 SmithSet
 
 Finds the innermost Smith Set (Dominant Set). [ assistance in finding proof of the algorithm used would be appreciated so it could be correctly referenced in this documentation ]. A Dominant Set is a set which defeats all choices outside of that set. The inner Smith Set is the smallest possible Dominant Set.
 
 Returns a hashref with the keys as the choices of the Smith Set.
 
-
 =head2 ResetActive
 
 Reset Active list to the choices list of the BallotSet.
 
-
 =head2 GreatestLoss
 
 Returns the greatest loss for a choice C<<< $MyMatrix->GreatestLoss( $A ) >>>.
 
-
 =head2 RankGreatestLoss
 
 Returns a RankCount object of the Greatest Loss for each choice.
 
 =cut
 
-#buildpod
-
 #FOOTER
 
 =pod
@@ -548,10 +518,15 @@ John Karr (BRAINBUZ) brainbuz@cpan.org
 
 CONTRIBUTORS
 
-Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+Copyright 2019-2021 by John Karr (BRAINBUZ) brainbuz@cpan.org.
 
 LICENSE
 
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
-=cut
\ No newline at end of file
+SUPPORT
+
+This software is provided as is, per the terms of the GNU Public License. Professional support and customisation services are available from the author.
+
+=cut
+
