@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-use 5.022;
+use 5.024;
 use feature qw /postderef signatures/;
 
 package Vote::Count::Method::STAR;
@@ -8,13 +8,13 @@ use namespace::autoclean;
 use Moose;
 extends 'Vote::Count';
 
-our $VERSION='1.10';
+our $VERSION='2.00';
 
 =head1 NAME
 
 Vote::Count::Method::STAR
 
-=head1 VERSION 1.10
+=head1 VERSION 2.00
 
 =cut
 
@@ -42,7 +42,11 @@ Scores the Range Ballots, then holds a runoff between the two highest scored cho
 
 =head2 Function Name: STAR
 
-Conducts and Logs STAR. Returns the winner or 0 in the event of a tie.
+Conducts and Logs STAR.
+
+Beginning with version 1.08 the STAR() method returns a Hash Ref similar to other Vote::Count Methods. The key 'tie' is true for a tie false otherwise, the key 'winner' contains the winning choice or 0 if there is a tie. When there is a tie an additional key 'tied' contains an Array Ref of the tied choices.
+
+When more than 2 choices are in a tie for the automatic runoff STAR() returns them as a tie.
 
 =head2 Criteria
 
@@ -52,7 +56,7 @@ The Range Ballot is more complex for voters than the Ranked Choice Ballot. The s
 
 =head3 Later Harm
 
-There is significantly less Later Harm with STAR than with other Borda methods. By ranking the preferred choice with the maximum score, and alternate choices very low, the voter is minimizing the later harm impact of those later choices. With 10 choices in regular Borda, the second choice would recieve 90% of the first choice's score, by ranking later choices at the bottom of the scale the impact is much lower.
+By ranking the preferred choice with the maximum score, and alternate choices very low, the voter is able to minimuze the later harm impact of those later choices. With 10 choices in regular Borda, the second choice would recieve 90% of the first choice's score, by ranking later choices at the bottom of the scale the impact is much lower.
 
 =head3 Condorcet Criteria
 
@@ -60,19 +64,13 @@ STAR only meets the Condorcet Loser Criteria. The runoff prevents a Condorcet Lo
 
 STAR does not meet the Smith and Condorcet Winner Criteria.
 
-More information is needed to know if in practice it performs better than IRV.
-
 =head3 Consistency
 
 STAR should meet Monotonacity. Adding a non-winning choice will have no impact on the outcome unless they can score high enough to reach and lose the runoff phase. Clone handling is dependent on the behavior of the clone group supporters, if they rank the clones far apart, the clone that attracts later support from non-clone supporters is likely to not reach the runoff.
 
-More information is needed to know if Clone handling is good or poor in practice, and whether there is a significant consistency failure of some other type.
+=head3 Strategic Voting
 
-=head2 Implementation Notes
-
-Beginning with version 1.08 the STAR() method returns a Hash Ref similar to other Vote::Count Methods. The key 'tie' is true for a tie false otherwise, the key 'winner' contains the winning choice or 0 if there is a tie. When there is a tie an additional key 'tied' contains an Array Ref of the tied choices.
-
-When more than 2 choices are in a tie for the automatic runoff STAR() returns them as a tie.
+STAR creates strong incentive for strategic voting. The voter must decide to either mitigate later harm, or to show strong support for their secondary choices. Even when the voter decides to rate the choices accurately, it is a greater effort than ranking them.
 
 =cut
 
@@ -150,11 +148,15 @@ John Karr (BRAINBUZ) brainbuz@cpan.org
 
 CONTRIBUTORS
 
-Copyright 2019 by John Karr (BRAINBUZ) brainbuz@cpan.org.
+Copyright 2019-2021 by John Karr (BRAINBUZ) brainbuz@cpan.org.
 
 LICENSE
 
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
+SUPPORT
+
+This software is provided as is, per the terms of the GNU Public License. Professional support and customisation services are available from the author.
+
 =cut
 
